@@ -36,9 +36,7 @@
  * #ClutterDeviceManager is available since Clutter 1.2
  */
 
-#ifdef HAVE_CONFIG_H
 #include "clutter-build-config.h"
-#endif
 
 #include "clutter-backend-private.h"
 #include "clutter-debug.h"
