@@ -300,7 +300,7 @@ cogl_color_unpremultiply (CoglColor *color)
     }
 }
 
-CoglBool
+gboolean
 cogl_color_equal (const void *v1, const void *v2)
 {
   const uint32_t *c1 = v1, *c2 = v2;
