@@ -56,7 +56,7 @@
 #define GL_RG8 0x822B
 #endif
 
-static CoglBool
+static gboolean
 _cogl_driver_pixel_format_from_gl_internal (CoglContext *context,
                                             GLenum gl_int_format,
                                             CoglPixelFormat *out_format)
@@ -232,7 +232,7 @@ _cogl_driver_pixel_format_to_gl (CoglContext *context,
                                                       out_gltype);
 }
 
-static CoglBool
+static gboolean
 _cogl_get_gl_version (CoglContext *ctx,
                       int *major_out,
                       int *minor_out)
@@ -251,7 +251,7 @@ _cogl_get_gl_version (CoglContext *ctx,
                                          minor_out);
 }
 
-static CoglBool
+static gboolean
 _cogl_driver_update_features (CoglContext *context,
                               CoglError **error)
 {
