@@ -176,10 +176,10 @@ prepare_bitmap_alignment_for_upload (CoglContext *ctx,
     return _cogl_bitmap_copy (src_bmp, error);
 }
 
-static CoglBool
+static gboolean
 _cogl_texture_driver_upload_subregion_to_gl (CoglContext *ctx,
                                              CoglTexture *texture,
-                                             CoglBool is_foreign,
+                                             gboolean is_foreign,
                                              int src_x,
                                              int src_y,
                                              int dst_x,
@@ -199,7 +199,7 @@ _cogl_texture_driver_upload_subregion_to_gl (CoglContext *ctx,
   int bpp = _cogl_pixel_format_get_bytes_per_pixel (source_format);
   CoglBitmap *slice_bmp;
   int rowstride;
-  CoglBool status = TRUE;
+  gboolean status = TRUE;
   CoglError *internal_error = NULL;
   int level_width;
   int level_height;
@@ -326,11 +326,11 @@ _cogl_texture_driver_upload_subregion_to_gl (CoglContext *ctx,
   return status;
 }
 
-static CoglBool
+static gboolean
 _cogl_texture_driver_upload_to_gl (CoglContext *ctx,
                                    GLenum gl_target,
                                    GLuint gl_handle,
-                                   CoglBool is_foreign,
+                                   gboolean is_foreign,
                                    CoglBitmap *source_bmp,
                                    GLint internal_gl_format,
                                    GLuint source_gl_format,
@@ -345,7 +345,7 @@ _cogl_texture_driver_upload_to_gl (CoglContext *ctx,
   CoglBitmap *bmp;
   uint8_t *data;
   CoglError *internal_error = NULL;
-  CoglBool status = TRUE;
+  gboolean status = TRUE;
 
   bmp = prepare_bitmap_alignment_for_upload (ctx, source_bmp, error);
   if (!bmp)
@@ -394,11 +394,11 @@ _cogl_texture_driver_upload_to_gl (CoglContext *ctx,
   return status;
 }
 
-static CoglBool
+static gboolean
 _cogl_texture_driver_upload_to_gl_3d (CoglContext *ctx,
                                       GLenum gl_target,
                                       GLuint gl_handle,
-                                      CoglBool is_foreign,
+                                      gboolean is_foreign,
                                       GLint height,
                                       GLint depth,
                                       CoglBitmap *source_bmp,
@@ -543,7 +543,7 @@ _cogl_texture_driver_upload_to_gl_3d (CoglContext *ctx,
 /* NB: GLES doesn't support glGetTexImage2D, so cogl-texture will instead
  * fallback to a generic render + readpixels approach to downloading
  * texture data. (See _cogl_texture_draw_and_read() ) */
-static CoglBool
+static gboolean
 _cogl_texture_driver_gl_get_tex_image (CoglContext *ctx,
                                        GLenum gl_target,
                                        GLenum dest_gl_format,
@@ -553,7 +553,7 @@ _cogl_texture_driver_gl_get_tex_image (CoglContext *ctx,
   return FALSE;
 }
 
-static CoglBool
+static gboolean
 _cogl_texture_driver_size_supported_3d (CoglContext *ctx,
                                         GLenum gl_target,
                                         GLenum gl_format,
@@ -572,7 +572,7 @@ _cogl_texture_driver_size_supported_3d (CoglContext *ctx,
   return width <= max_size && height <= max_size && depth <= max_size;
 }
 
-static CoglBool
+static gboolean
 _cogl_texture_driver_size_supported (CoglContext *ctx,
                                      GLenum gl_target,
                                      GLenum gl_intformat,
@@ -599,7 +599,7 @@ _cogl_texture_driver_try_setting_gl_border_color
   /* FAIL! */
 }
 
-static CoglBool
+static gboolean
 _cogl_texture_driver_allows_foreign_gl_target (CoglContext *ctx,
                                                GLenum gl_target)
 {
