@@ -2,6 +2,7 @@
 
 /*
  * Copyright (C) 2017 Red Hat
+ * Copyright (C) 2018 DisplayLink (UK) Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -25,10 +26,19 @@
 #include <xf86drm.h>
 #include <xf86drmMode.h>
 
+#include "backends/meta-backend-types.h"
 #include "backends/meta-crtc.h"
-#include "backends/meta-gpu.h"
 #include "backends/native/meta-gpu-kms.h"
 
+typedef struct _MetaDrmFormatBuf
+{
+  char s[5];
+} MetaDrmFormatBuf;
+
+const char *
+meta_drm_format_to_string (MetaDrmFormatBuf *tmp,
+                           uint32_t          format);
+
 gboolean meta_crtc_kms_is_transform_handled (MetaCrtc             *crtc,
                                              MetaMonitorTransform  transform);
 
@@ -40,6 +50,13 @@ void meta_crtc_kms_set_underscan (MetaCrtc *crtc,
 GArray * meta_crtc_kms_get_modifiers (MetaCrtc *crtc,
                                       uint32_t  format);
 
+GArray *
+meta_crtc_kms_copy_drm_format_list (MetaCrtc *crtc);
+
+gboolean
+meta_crtc_kms_supports_format (MetaCrtc *crtc,
+                               uint32_t  drm_format);
+
 MetaCrtc * meta_create_kms_crtc (MetaGpuKms   *gpu_kms,
                                  drmModeCrtc  *drm_crtc,
                                  unsigned int  crtc_index);
