@@ -70,10 +70,6 @@ struct _MetaWaylandSerial {
   uint32_t value;
 };
 
-#define META_TYPE_WAYLAND_SURFACE_ROLE_DND (meta_wayland_surface_role_dnd_get_type ())
-
-GType meta_wayland_surface_role_dnd_get_type (void);
-
 struct _MetaWaylandPendingState
 {
   GObject parent;
@@ -113,6 +109,11 @@ struct _MetaWaylandPendingState
 
   gboolean has_new_buffer_transform;
   MetaMonitorTransform buffer_transform;
+  gboolean has_new_viewport_src_rect;
+  ClutterRect viewport_src_rect;
+  gboolean has_new_viewport_dst_size;
+  int viewport_dst_width;
+  int viewport_dst_height;
 };
 
 struct _MetaWaylandDragDestFuncs
@@ -148,6 +149,8 @@ struct _MetaWaylandSurface
   GHashTable *outputs_to_destroy_notify_id;
   MetaMonitorTransform buffer_transform;
 
+  CoglTexture *texture;
+
   /* Buffer reference state. */
   struct {
     MetaWaylandBuffer *buffer;
@@ -202,6 +205,19 @@ struct _MetaWaylandSurface
     GSList *pending_placement_ops;
   } sub;
 
+  /* wp_viewport */
+  struct {
+    struct wl_resource *resource;
+    gulong destroy_handler_id;
+
+    gboolean has_src_rect;
+    ClutterRect src_rect;
+
+    gboolean has_dst_size;
+    int dst_width;
+    int dst_height;
+  } viewport;
+
   /* table of seats for which shortcuts are inhibited */
   GHashTable *shortcut_inhibited_seats;
 };
@@ -303,6 +319,8 @@ void                meta_wayland_surface_restore_shortcuts (MetaWaylandSurface *
 gboolean            meta_wayland_surface_is_shortcuts_inhibited (MetaWaylandSurface *surface,
                                                                  MetaWaylandSeat    *seat);
 
+CoglTexture *       meta_wayland_surface_get_texture (MetaWaylandSurface *surface);
+
 MetaSurfaceActor *  meta_wayland_surface_get_actor (MetaWaylandSurface *surface);
 
 void                meta_wayland_surface_notify_geometry_changed (MetaWaylandSurface *surface);
